@@ -10,6 +10,7 @@ class SRTReader(BaseReader):
             return False
 
     def read(self, content, lang='en-US'):
+        content = self.force_byte_string(content)
         caption_set = CaptionSet()
         lines = content.splitlines()
         start_line = 0
@@ -30,8 +31,8 @@ class SRTReader(BaseReader):
             for line in lines[start_line + 2:end_line - 1]:
                 # skip extra blank lines
                 if not caption.nodes or line != '':
-                  caption.nodes.append(CaptionNode.create_text(line))
-                  caption.nodes.append(CaptionNode.create_break())
+                    caption.nodes.append(CaptionNode.create_text(line))
+                    caption.nodes.append(CaptionNode.create_break())
 
             # remove last line break from end of caption list
             caption.nodes.pop()
@@ -57,14 +58,12 @@ class SRTReader(BaseReader):
     def _find_text_line(self, start_line, lines):
         end_line = start_line + 1
 
-        while end_line < (len(lines) + 1):
-            try:
-                int(lines[end_line])
-                break
-            except (ValueError, IndexError):
-                end_line += 1
+        while end_line < len(lines):
+            if lines[end_line].strip() == "":
+                return end_line + 1
+            end_line += 1
 
-        return end_line
+        return end_line + 1
 
 
 class SRTWriter(BaseWriter):
@@ -72,9 +71,12 @@ class SRTWriter(BaseWriter):
         srt_captions = []
 
         for lang in captions.get_languages():
-            srt_captions.append(self._recreate_lang(captions.get_captions(lang)))
+            srt_captions.append(
+                self._recreate_lang(captions.get_captions(lang))
+            )
 
-        return 'MULTI-LANGUAGE SRT\n'.join(srt_captions)
+        caption_content = 'MULTI-LANGUAGE SRT\n'.join(srt_captions)
+        return self.force_byte_string(caption_content)
 
     def _recreate_lang(self, captions):
         srt = ''
@@ -94,7 +96,7 @@ class SRTWriter(BaseWriter):
             srt += '\n\n'
             count += 1
 
-        return srt[:-1] # remove unwanted newline at end of file
+        return srt[:-1]  # remove unwanted newline at end of file
 
     def _recreate_line(self, srt, line):
         if line.type == CaptionNode.TEXT:
